===============================
QuickBooks Python Client
===============================

.. image:: https://img.shields.io/pypi/v/quickbooks-py.svg
        :target: https://pypi.python.org/pypi/quickbooks-py

Python Library for interfacing with Quickbooks Accounting API v3 found at
https://developer.intuit.com/docs/api/accounting

* Free software: ISC license
